\name{PaulKAI}
\alias{PaulKAI}
\title{Occurences of ``kai'' in 10 Epistels of Apostel Paul}
\usage{data(PaulKAI)}
\description{
  These are the numbers of sentences which have
  0, 1, 2, or 3 and more (\code{3+}) occurrences of the greek word
  ``kai'' (which means ``and'' and more) in 10 epistles of Apostel Paul,
  see the reference.
}
\format{
  A \eqn{10 \times 4}{10 x 4} matrix with proper \code{\link{dimnames}},
  see the examples below.
}
\note{
  One theological question is about the authorship of ``Hebrews'' (the
  last epistle in our matrix), so one might be interested in its ``kai
  pattern'' compared to, e.g. ``Romans''.
}
\references{
  Morton, A. Q. (1965) \cr
  The authorship of Greek prose (with discussion).\cr
  Journal of the Royal Statistical Society, Series A, \bold{128}, 169--233.

  Posted to S-news by Jim Ramsay, see \code{\link{quadplot}}.
}
\keyword{datasets}
\seealso{\code{\link{quadplot}} for which this data set was used as
  illustration.}
\examples{
data(PaulKAI)
rownames(PaulKAI) # the ten epistles researched:
##>  [1] "Rom" "Co1" "Co2" "Gal" "Phi" "Col" "Th1" "Ti1" "Ti2" "Heb"
PaulKAI # the 10 x 4 count table
mosaicplot(PaulKAI)
quadplot(PaulKAI)
}
\name{laser}
\alias{laser}
\title{Bellcore Experimental Laser Data}
\usage{data(laser)}
\description{
    This data came from an investigation of an experimental laser at
    Bellcore.  It was a tunable laser, in the sense that both its
    wavelength and power output were controllable.}
\details{
    Rotation helped the experimental physicists to characterize the
    laser, which turned out not to be a very good one, due to its
    unstable operating region.

    This data initially came to the statistics research group when
    Janette Cooper asked Paul Tukey to help her analyze the data she had
    collected to describe the laser.}
\format{
    A data frame with observations on the variables \code{If} and
    \code{Ir} (the currents applied to the front and rear of the laser),
    and \code{power} and \code{lambda} (the output power and
    wavelength).
}
\keyword{datasets}
\name{morsecodes}
\alias{morsecodes}
\alias{morsecodes.col}
\alias{morsecodes.colors}
\alias{morsecodes.dist}
\alias{morsecodes.glyphs}
\alias{morsecodes.linecolors}
\alias{morsecodes.lines}
\alias{morsecodes.pos}
\alias{morsecodes.raw}
\alias{morsecodes.row}
\title{Rothkopf Morse Code Data}
\description{
  A standard data set for Multidimensional Scaling (MDS) obtained by
  Rothkopf based on the confusion rates observed by exposing subjects to
  pairs of morse codes.
}
\usage{data(morsecodes)}
\format{
  9 data sets used for analyzing the data in XGvis and XGobi.

  \tabular{ll}{
    \code{morsecodes.raw}    \tab 36 x 36 raw data of confusion rates \cr
    \code{morsecodes.dist}   \tab 36 x 36 dissimilarity matrix \cr
    \code{morsecodes.pos}    \tab 36 x 10 initial configuration \cr
    \code{morsecodes.colors} \tab 36 point colors \cr
    \code{morsecodes.glyphs} \tab 36 point glyphs \cr
    \code{morsecodes.lines}      \tab 33 lines \cr
    \code{morsecodes.linecolors} \tab 33 line colors \cr
    \code{morsecodes.row}   \tab 36 x 2 matrix of (letter, morsecode)\cr
    \code{morsecodes.col}   \tab 10 column names of the initial configuration
%% the *.raw code contain more information and the *.dist can be constructed
%% from them ... --> see /usr/local/app/xgobi/CURRENT/data_xgvis/morsecodes.doc
%%---> Copy the instructions there to the example of xgvis or here !
  }
}
\source{
  Contained in the \file{data\_xgvis} subdirectory of the XGobi and XGvis
  source bundle, available via
  \url{http://www.research.att.com/areas/stat/xgobi/index.html#download}.
}
\details{
  The raw data from the XGvis directory may be read as
  \cr
  \code{mc.raw <- as.matrix(read.table("....xgobi/data_xgvis/morsecodes.raw"))}
  \cr
  \code{dimnames(mc.raw) <- NULL; storage.mode(mc.raw) <- "integer"}
  \cr
  \code{morsecodes.raw <- mc.raw}.

  The \code{*.dist} matrix is produced from the raw data by
  \cr
  \code{mc.sim <- (mc.raw + t(mc.raw))/2 ;  ds <- diag(mc.sim)}
  \cr
  \code{morsecodes.dist <- rep(ds,36) + rep(ds,rep(36,36)) - 2*mc.sim},
  \cr
  i.e., \eqn{d_{ij} := s_{ii} + s_{jj} - 2 s_{ij}}{d[i,j] := s[i,i] +
    s[j,j] - 2 * s[i,j]}.
}
\references{
  A. Buja, D. F. Swayne, M. Littman, & N. Dean (1998).
  \emph{XGvis: Interactive Data Visualization with Multidimensional
    Scaling}.
  \url{http://www.research.att.com/areas/stat/xgobi/xgvis98.ps.gz}.
}
\examples{
data(morsecodes)
ls.str(pat="^morsecode")
morsecodes.row # remember what you learned in...
## real row names
(mc.row <- paste(morsecodes.row[,1], morsecodes.row[,2]))[1:8]

image(1:36, 1:36, morsecodes.raw, main="`morsecodes' raw confusion rates")
text(1:36,1:36, morsecodes.row[,1])

##--> help(xgvis) for running multidimensional scaling (MDS) and XGobi on these
}
\keyword{datasets}
\name{quadplot}
\title{Tetrahedral Display for Four-Category Proportions using XGobi}
\alias{quadplot}
\description{
  Four-category proportions are visualized as points inside a tetrahedron,
  using \code{\link{xgobi}}.
}
\details{
  The set of all four-category proportions, or, alternatively,
  probability measures on finite probability fields with 4 atomic
  events, is the set of nonnegative 4-vectors whose components sum up to
  1.  The function \code{quadplot} uses \code{xgobi} to represent such
  vectors graphically as points inside a tetrahetron with height 1: the
  four components of the vector are the distances of the point to each
  of the sides of the tetrahetron.  Each vertex of the tetrahedron
  corresponds to the degenerate probability distribution in which one of
  the atomic events has probability 1 and the others have probability 0.
  The labels of these vertices indicate the event which has probability 1.
}
\usage{
quadplot(mat4,
         pointlabs  = rownames(mat4),
         vertexlabs = paste(1:4),
         normalize  = median(abs(c(mat4))) > 1)
}
\arguments{
  \item{mat4}{matrix with 4 columns containing the data}
  \item{pointlabs}{character array of labels for rows of data;
    by default it is the row number as a string.}
  \item{vertexlabs}{character array of length 4 of labels for the vertices;
    by default it is the column number as a string.}
  \item{normalize}{logical variable indicating whether or not to force
    each row of data to have unit sum before display, default is false.}
}
\references{
  \code{quadplot} was posted by Jim Ramsay \email{ramsay@psych.mcgill.ca}
  to S-news on Fri, 21 May 1993 14:03:15 EDT.
}
\author{(port to \R)
  Hans Ehrbar \email{ehrbar@econ.utah.edu} and Martin Maechler
  (with explicit permission from Jim Ramsay)
}
\examples{
data(PaulKAI)
quadplot(PaulKAI, normalize = TRUE)
}
\keyword{dynamic}
\keyword{hplot}

\name{reggeom}
\alias{reggeom}

\title{Geometry of Regression with Two Regressors}

\description{
  Using XGobi for visualising the geometry of regression with two
  explanatory variables.

  The function \code{reggeom} has exactly the same arguments as
  \code{\link{xgobi}(..)}, and it simply calls \code{xgobi}, but it has
  different default values for the arguments than the defaults of
  \code{xgobi} itself.
}
\usage{
reggeom()
}
\synopsis{
reggeom(matrx = matrix(c(0, 5780, -1156, 3468, 3468, 3468,
	    -867, 4335, 0, 0, -612, 4080, 5440, 2652, 3468, 3420, 3468,
	    0, 0, 4624, 3468, 3468, 0, 3468, 0, 3468, 4624, 2448, 1020,
	    1360, 3264, 3264, 3456, 3456, 0, 0, 0, 4624, 0, 0, 0, 0,
	    0, 0, 0, 0, 0, 0, 0, 0, 0), nrow = 17, ncol = 3),
    collab = c("U", "V", "W"),
    rowlab = c("o", "x1", "x2", "y",
               "b", "c", "d", "e", "f", "g", "h",
               "k", "m", "p", "q", "r", "s"),
    colors = NULL, glyphs = NULL, erase = NULL,
    lines = matrix(c(1,  6, 8, 1, 11, 7, 1, 1, 5, 6,
                       6, 15, 17, 8, 5, 9, 1, 9, 10,
                     6, 8, 2, 11, 7, 3, 4, 5, 4, 4,
                       15, 17, 5, 5, 9, 7, 9, 10, 3),
                    nrow = 19, ncol = 2),
    linecolors = c("red", "yellow", "yellow", "yellow", "yellow",
        "yellow", "orchid", "green", "green", "red", "skyblue",
        "skyblue", "skyblue", "white", "white", "white", "slateblue",
        "slateblue", "slateblue"),
    resources = c("*showLines: True", "*showAxes: False", "*showPoints: False",
        "*XGobi*PlotWindow.height: 500",
        "*XGobi*PlotWindow.width: 500", "*XGobi*VarPanel.width: 50"),
    title = "Regression Geometry", vgroups = c(1, 1, 1), std = "msd",
    nlinkable = NULL, subset = NULL, display = NULL)
}
\arguments{
  \item{matrx}{
    the default dataset is a matrix with three columns.
    The rows represent the dependent and the two independent variables,
    as well as fitted values and residuals in the regression on one
    or both regressors, and other auxiliary variables.
    Since the matrix has three columns, each variable is
    represented as a vector in 3-dimensional space.
  }
  \item{collab}{
    column labels for \code{matrx}, by default \code{"U"}, \code{"V"}, and
    \code{"W"}, not very meaningful since the columns represent
    oblique directions in n-dimensional space.
  }
  \item{rowlab}{character vector of labels for the variables;
    by default, "x1" and "x2" for the independent and "y" for the
    dependent variable, "o" for the origin, and other letters for the
    auxiliary variables.
  }
  \item{colors}{as in \code{xgobi} all points are of the same color.}
  \item{glyphs}{as in \code{xgobi} all points are drawn with the same glyph.  }
  \item{erase}{as in \code{xgobi} no points will be erased.}
  \item{lines}{the default \code{lines} argument displays some of the data in
    \code{matrx} as straight lines.  The user may want to substitute
    different lines in order to emphasize or de-emphasize certain
    relationships, as in the example given below.
  }
  \item{linecolors}{
    The default line colors are:
    \describe{
      \item{purple}{for the dependent variable,}
      \item{yellow}{for the two independent variables,}
      \item{green}{for fitted values and residuals in the full regression,}
      \item{red}{for fitted values and residuals in the regression
	on the first independent variable only, and}
      \item{light blue}{,}
      \item{dark blue}{, and}
      \item{white}{for auxiliary lines.}
    }
  }
  \item{resources}{by default, points and axes are not shown; only lines
    are.}
  \item{title}{by default, \code{"Regression Geometry"}}
  \item{vgroups}{by default, all three variables are in the same group.}
  \item{std}{by default, the view is centered on the mean of the data.}
  \item{nlinkable, subset, display}{the same as in \code{\link{xgobi}}.}
}
\value{
  As in the call of \code{\link{xgobi}},
  the UNIX \code{status} upon completion, i.e. \code{0} if ok.
}
\details{
  If called without arguments, \code{reggeom} loads a dataset which
  represents the geometry of regression with two explanatory variables.
  The idea is to place the dataset into the rotation view in order to
  get an intuition of the geometry involved.  \code{reggeom} should only
  then be called with arguments if specific built-in defaults must be
  overriden.

  The explanatory variables are x1=(5,0,0) and x2=(-1,4,0),
  and the target (dependent) variable is y=(3,3,4).
  However all coordinates are multiplied by 1156,
  with the effect that all the points passed as arguments to
  \code{xgobi} have integer coordinates.
}
\seealso{\code{\link{xgobi}}
}
\section{Side Effects}{
    As in \code{xgobi}.
}
\references{
  \code{reggeom} can be considered a 3-dimensional visualization
  of the figures in Davidson, R. and MacKinnon, J. G. (1993)
  \emph{Estimation and Inference in Economics}, Oxford University
  Press, p. 22.

  The chapter ``Additional Regressors'' in Hans Ehrbar's on-line
  econometrics class notes
  \url{http://www.econ.utah.edu/ehrbar/ecmet.pdf}
  uses \code{reggeom} for teaching and has several exercise
  questions about it.
}
\section{author}{Hans Ehrbar \email{ehrbar@econ.utah.edu}}
\examples{
## The arguments given in this example are modifications of the default,
## some lines dropped, some added, some line colors changed,
## in order to emphasize the geometry of backfitting.

reggeom(
      lines= cbind(c(1,6,8,1,11,7,1,1,6,6,15,17,8,5,9, 5,6,14,15,16,14,15,5),
                   c(6,8,2,11,7,3,4,5,4,15,17,5,5,9,7,11,14,15,16,17,4,4,4)),
      linecolors=c("red", rep("yellow",5), "orchid", "green",
                   "slateblue", rep("skyblue",3), rep("white",3), "skyblue",
                   rep("red",4), rep("slateblue", 2), "green"),
      title="Regression Geometry - Backfitting")
}
\keyword{dynamic}

\name{xgobi}
\title{XGobi: Dynamic Graphics for Data Analysis}
\alias{xgobi}
\alias{xgobi.colors.default}
\description{
  Dynamic graphics, including  brushing, rotation, grand tour, projection
  pursuit, slicing.  Most effectively used when called more than once on same
  data, which then allows linked plots.  Brushing with several glyphs and
  colors is supported.  (On monochrome displays, only glyphs can be used.)
}
\usage{
xgobi(matrx,
      collab = dimnames(matrx)[[2]],
      rowlab = dimnames(matrx)[[1]],
      colors = NULL, glyphs = NULL, erase = NULL,
      lines = NULL, linecolors = NULL, resources = NULL,
      title = deparse(substitute(matrx)),
      vgroups = NULL, std = "mmx",
      nlinkable = NULL, subset = NULL, display = NULL,
      keep = FALSE, fprefix = "xgobi-")

xgobi.colors.default
}
\arguments{
  \item{matrx}{numeric \code{n * p} matrix or data.frame.}
  \item{collab}{
    character vector of \code{p} column labels (defaulting to those of
    \code{matrx}); if no default exists, \code{\link{xgobi}} constructs
    its own (\code{"Var1"},....).}
  \item{rowlab}{
    character vector of \code{n} row labels (defaulting to those of
    \code{matrx}); if no default exists, \code{\link{xgobi}} constructs
    its own (numbers \code{1:n}).}
  \item{colors}{
    Optional character vector, used to supply initial point colors to be used;
    the default is that all points are the same color.  Details, see below.}
  \item{glyphs}{
    Optional integer vector, used to supply glyphs to be used on
    startup; the default is that all points are drawn with the same
    glyph.

    Glyphs have been coming as six different types (plus, X, open and
    filled rectangle, open and filled circle) in five different sizes,
    plus ``point'', giving 31 available glyphs.
  }
  \item{erase}{
    Optional integer vector of length equal to the number of rows in the
    data and composed of 1s and 0s.  A 1 in position i specifies that
    point i should be erased.  The default is a vector of 0s.
  }
  \item{lines}{
    Optional integer matrix, n by 2, which specifies by row number
    pairs of points to be connected by line segments.  The default
    connecting line matrix connects each point to the one that follows
    it in the data; that is, (1 2), (2 3), (3 4), \dots{}, (n-1, n).
  }
  \item{linecolors}{
    Optional integer vector, of length n where n is the number of
    lines specified by the 'lines' argument.  It is used to supply
    line colors to be used on startup; the default is for all the
    lines to be drawn in the standard foreground color.
  }
  \item{resources}{
    Optional character vector created by clicking on the ``Save
    Resources'' button in XGobi (if this XGobi was initiated during
    an \R session).
  }
  \item{title}{
    Optional character string which defines the \code{-title} argument used by
    X. Defaults to the name (expression) of the current \code{matrx}
    argument.  See documentation for xgobi, or for X.
  }
  \item{vgroups}{
    Optional integer vector, used to assign columns to groups for
    transformation and axis scaling.  This vector must contain one integer
    for each variable.  Columns to be grouped together should share the
    same integer.  Default is the vector \code{1:(ncol(matrx))}.
  }
  \item{std}{
    Optional string; which standardization of view to use.  Default is
    \code{"mmx"}, minimum-maximum scaling, in which the view is centered
    at the midpoint of the data, and all the data fits inside the plotting
    window.  Alternatives are \code{"msd"}, in which the plot is
    centered at the mean of the data, or \code{"mmd"} in which the plot
    is centered at the median.
    In those two cases, the view is standardized using the largest distance.
  }
% \item{dev}{
%   Optional numeric scalar; the number of standard deviations (if \code{"msd"}
%   is chosen) or median absolute deviations (if \code{"mmd"} is chosen) that
%   will be plotted inside the plotting window.  Default is 2.
% }
  \item{nlinkable}{
    Optional integer scalar, the number of rows to be used in linking
    of brushing and identification;
    the default is for all rows to be used.  This feature can be used
    to link ordinary scatterplots with plots that have some decorations
    requiring additional points, such as clustering trees.
  }
  \item{subset}{
    Optional integer scalar, the number of rows to be included in the
    initial display.  That is, all data will be read in, but an
    initial random sample will be drawn for display.  Use the Subset
    panel on the Tools Menu to select a new subset during the session.
  }
  \item{display}{
    Optional character string, identifying the monitor on which to display
    the xgobi window.  The default is \code{"machine:0.0"} where
    \code{machine} is the name of the user's workstation.  See
    documentation for xgobi or for X.}
  \item{keep}{logical, indicating if the temporary files should be kept
    (e.g. for calling the \code{xgobi} program outside \R)}
  \item{fprefix}{character string for the \bold{f}ile name \bold{prefix}
    to be used for temporary files.}
}
\value{
  The UNIX \code{status} upon completion, i.e. \code{0} if ok.
}
\section{Side Effects}{
  The \R function \code{xgobi} executes a call to the C program of the
  same name,
  an interactive statistical graphics program which runs under the X
  Window System, and returns control of the \R command line to the user.

  XGobi can be used to create vectors of brushing information and rotation
  coefficients; see the documentation for XGobi for details.
}
\details{
  \code{xgobi.colors.default} is the vector of the ten default brush
  colors from which to choose by the \code{colors} argument.

  Note that this sef of default brush colors can be modified by a (site or
  user) specific \file{app-defaults} file, or directly by
  \code{xgobi(*, resources = ..)}, redefining (\code{*brushColor}\eqn{n}
  (with \eqn{n} from \code{0:9}).

  A warning is issued if \code{colors} contains strings not in the
  \code{brushColor} resources.
}
\references{
  \url{http://www.research.att.com/areas/stat/xgobi/}, \cr
  \url{http://www.public.iastate.edu/~dicook/}
}
\author{of \R port: Kurt Hornik and
  Martin Maechler \email{maechler@stat.math.ethz.ch}}
\section{CONTACT}{(xgobi main program):
  D. F. Swayne \email{dfs@research.att.com}
}
\seealso{\code{\link{xgvis}} which uses \code{xgobi} for interactive MDS.
}
\examples{
data(laser)
xgobi(laser)

system("mkdir /tmp/xgobi")
xgobi(laser, colors = xgobi.colors.default[c(1,3,5,7,9,10)[as.factor(laser$ Ir)]],
      glyphs = c(23,8)[1+(laser$lambda > 1576)],
      keep = TRUE, fprefix="xgobi/L-")
system("ls -l /tmp/xgobi")# >> Files "L-laser..."
## remove manually when finally unused:
system("rm /tmp/xgobi/L-*")

##>>> see also the morsecodes example in  help(xgvis) <<<
##                 ------------------     -----------
}
\keyword{dynamic}
\keyword{multivariate}
\name{xgvis}
\alias{xgvis}
\title{XGvis: Interactive Multidimensional Scaling Using XGobi for Display}
\description{
  \R interface to \code{XGvis}, an interactive multidimensional scaling
  (MDS) program that consists of a control panel to manipulate the
  parameters of the MDS stress function and an \code{\link{xgobi}}
  window for data display.  It can be used either for visualization of
  dissimilarity data, for dimension reduction, or for graph layout.
  Graph layout is usually done in 2D, but \code{xgvis} allows layouts in
  arbitrary dimensions, 3D being the default.  It permits missing
  values, which can be used to implement multidimensional unfolding.
}
\usage{
xgvis(dmat = NULL,
      edges= NULL,
      pos  = NULL,
      rowlab = dimnames(dmat)[[1]],
      colors = NULL, glyphs = NULL,
      erase = NULL, lines = NULL, linecolors = NULL,
      resources = NULL, display = NULL,
      keep = FALSE, fprefix = "xgvis-")
)
}
\arguments{
  \item{dmat}{numeric \eqn{n \times n}{n * n} distance matrix.}
  \item{edges}{\eqn{n \times 2}{n * 2} or \eqn{n \times 3}{n * 3} matrix of
    specifications for the pattern of line segments which
    connect pairs of points.  Must contain at least two numbers per
    line.  The first two numbers represent the row numbers of the two
    points that should be connected.  (This is exactly like the structure
    of a the \code{lines} argument of \code{\link{xgobi}}.)  In addition,
    if a third number is present, it is taken to be an edge weight.

    If \code{edges} is specified and \code{dmat} not, then
    the distance matrix is computed from \code{edges}, with each
    edge representing a distance of one.
  }
  \item{pos}{
    Starting positions: an \code{n * p} matrix.
    If \code{pos} is specified and \code{dmat} not,
    the distance matrix is computed from \code{pos}.}
  \item{rowlab}{
    character vector of \code{n} row labels (defaulting to those of
    \code{dmat}); if no default exists, \code{\link{xgobi}} constructs
    its own (numbers \code{1:n}).}
  \item{colors}{optional character vector supplying initial point colors
    to be used; see \code{\link{xgobi}}.}
  \item{glyphs}{integer vector, used to supply glyphs to be used on
    startup, see \code{\link{xgobi}}.}
  \item{erase}{
    Optional integer vector of length equal to the number of rows in the
    data and composed of 1s and 0s.  A 1 in position i specifies that
    point i should be erased.  The default is a vector of 0s.}
  \item{lines}{
    Optional integer matrix, n by 2, which specifies by row number
    pairs of points to be connected by line segments.
    If \code{lines} are specified, then the \code{edges} is used to create
    the distance matrix but \code{lines} is used to draw the edges.
  }
  \item{linecolors}{
    Optional integer vector, of length n where n is the number of
    lines specified by the \code{lines} argument.  It is used to supply
    line colors to be used on startup; the default is for all the
    lines to be drawn in the standard foreground color.
  }
  \item{resources}{
    Optional character vector created by clicking on the ``Save
    Resources'' button in XGobi.
    %(if this XGvis was initiated during an R session).
  }
  \item{display}{
    Optional character string, identifying the monitor on which to display
    the xgvis window.  The default is \code{"machine:0.0"} where
    \code{machine} is the name of the user's workstation.  See
    documentation for X.
  }
  \item{keep}{logical, indicating if the temporary files should be kept
    (e.g. for calling the \code{xgobi} program outside \R)}
  \item{fprefix}{character string for the \bold{f}ile name \bold{prefix}
    to be used for temporary files.}
}
\value{
  The UNIX \code{status} upon completion, i.e. \code{0} if ok.
}
\section{Side Effects}{
  The xgvis \R function executes a call to the C program of the same name,
  and returns control of the \R command line to the user.
}
\references{
  \url{http://www.research.att.com/areas/stat/xgobi/}, \cr
  \url{http://www.public.iastate.edu/~dicook/}
}
\author{of \R port: Kurt Hornik and
  Martin Maechler \email{maechler@stat.math.ethz.ch}}
\section{CONTACT}{
  D. F. Swayne \email{dfs@research.att.com}
}
\seealso{\code{\link{xgobi}}.}
\examples{
data(morsecodes) ## from the XGobi/XGvis data, see  ?morsecodes
mc.row <- paste(morsecodes.row[,1],morsecodes.row[,2])

xgvis(dmat = morsecodes.dist,
      pos = morsecodes.pos,
      rowlab = mc.row,
      colors = morsecodes.colors,
      glyphs = morsecodes.glyphs,
      lines = morsecodes.lines,
      linecolors = morsecodes.linecolors)

##>   2) Show lines by hitting "l" with the mouse over the plot.
##>   3) Examine morsecode labels by hitting "i" and mousing around on the plot.
##>   3b) Press "r" (on the plot) to switch 3D rotation in xgobi.
##>   4) Run MDS in 3D by clicking "Run MDS" (in xgvis).
##>   5) Speed up the optimization by increasing the "Stepsize" with the slider.
##>      The "Stress function" value may go as low as 0.1925 (MM).
##>   6) When the optimization calms down, click "Run MDS" to toggle MDS off.
##>   7) Rotate the MDS configuration in 3D {by "r" with mouse over plot}.
##>   8) Increase the rotation speed with the slider in the top left and
##>      control the rotation direction by dragging the mouse on the plot.
##>   9) You can check out the initial configuration by

## In order to have no color warning :
Mcolors <- unique(morsecodes.colors)
(Mcolors <- paste("*brushColor", 0:(length(Mcolors)-1),": ", Mcolors, sep=""))

xgobi(morsecodes.pos, collab = morsecodes.col, rowlab = mc.row,
      colors = morsecodes.colors,
      glyphs = morsecodes.glyphs,
      lines  = morsecodes.lines,
      linecolors = morsecodes.linecolors,
      resources= c("*showLines: True", Mcolors))

##>      This XGobi window will be linked with
##>      the XGvis window for glyph-color brushing and labeling.
}
\keyword{dynamic}
\keyword{multivariate}

